/// <reference types="node" />
import { EventEmitter } from 'events';
import _ from 'lodash';
import { Environment } from 'nunjucks';
import { GetNodeListParams, PossibleProviderType } from '../provider';
import { ArtifactConfig, CommandConfig, PossibleNodeConfigType, RemoteSnippet } from '../types';
export interface ArtifactOptions {
    readonly remoteSnippetList?: ReadonlyArray<RemoteSnippet>;
    readonly templateEngine?: Environment;
}
export type ExtendableRenderContext = Record<string, string>;
export declare class Artifact extends EventEmitter {
    surgioConfig: CommandConfig;
    artifact: ArtifactConfig;
    private options;
    initProgress: number;
    providerNameList: ReadonlyArray<string>;
    nodeConfigListMap: Map<string, ReadonlyArray<PossibleNodeConfigType>>;
    providerMap: Map<string, PossibleProviderType>;
    nodeList: PossibleNodeConfigType[];
    private customFilters;
    private netflixFilter;
    private youtubePremiumFilter;
    constructor(surgioConfig: CommandConfig, artifact: ArtifactConfig, options?: ArtifactOptions);
    get isReady(): boolean;
    getRenderContext(extendRenderContext?: ExtendableRenderContext): {
        readonly netflixFilter: NonNullable<((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined>;
        readonly youtubePremiumFilter: NonNullable<((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined>;
        readonly customFilters: Record<string, ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        }>;
        readonly customParams: Readonly<Record<string, any>>;
        readonly usFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly hkFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly japanFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly koreaFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly singaporeFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly taiwanFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly chinaBackFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly chinaOutFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly shadowsocksFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly shadowsocksrFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly vmessFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly v2rayFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly snellFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly tuicFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly httpFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly httpsFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly trojanFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly socks5Filter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly wireguardFilter: (nodeConfig: PossibleNodeConfigType) => boolean;
        readonly proxyTestUrl: string | undefined;
        readonly proxyTestInterval: number | undefined;
        readonly internetTestUrl: string | undefined;
        readonly internetTestInterval: number | undefined;
        readonly downloadUrl: string;
        readonly snippet: (filePath: string) => RemoteSnippet;
        readonly remoteSnippets: _.Dictionary<RemoteSnippet>;
        readonly nodeList: PossibleNodeConfigType[];
        readonly provider: string;
        readonly providerName: string;
        readonly artifactName: string;
        readonly getDownloadUrl: (name: string) => string;
        readonly getUrl: (p: string) => string;
        readonly getNodeNames: (list: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined, separator?: string | undefined) => string;
        readonly getClashNodes: (list: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => NonNullable<{
            plugin?: string | undefined;
            readonly 'client-fingerprint'?: string | undefined;
            'plugin-opts'?: {
                mode: "tls" | "http" | "ws" | "wss";
                host: string | undefined;
            } | {
                host: string | undefined;
                path: string;
                mux: boolean;
                headers: _.Omit<Record<string, string>, "host">;
                'skip-cert-verify'?: boolean | undefined;
                mode: string;
                tls: boolean;
            } | {
                host?: string | undefined;
                version?: string | number | undefined;
                password: string;
                mode?: undefined;
            } | undefined;
            readonly type: "ss";
            readonly cipher: string;
            readonly name: string;
            readonly password: string;
            readonly port: string | number;
            readonly server: string;
            readonly udp: boolean;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly username?: undefined;
            readonly tls?: undefined;
            readonly 'skip-cert-verify'?: undefined;
        } | {
            readonly 'ws-opts'?: {
                path: string | undefined;
                headers: {
                    host?: string | undefined;
                };
            } | undefined;
            readonly 'skip-cert-verify'?: boolean | undefined;
            readonly tls: boolean;
            readonly network?: "ws" | undefined;
            readonly type: "vmess";
            readonly cipher: "none" | "aes-128-gcm" | "chacha20-ietf-poly1305" | "auto";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly udp: boolean;
            readonly uuid: string;
            readonly alterId: string | number;
            readonly password?: undefined;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly username?: undefined;
        } | {
            readonly type: "ssr";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly password: string;
            readonly obfs: string;
            readonly protocol: string;
            readonly cipher: string;
            readonly 'obfs-param': string;
            readonly 'protocol-param': string;
            readonly udp: boolean;
            readonly username?: undefined;
            readonly tls?: undefined;
            readonly 'skip-cert-verify'?: undefined;
        } | {
            readonly version?: string | number | undefined;
            readonly type: "snell";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly psk: string;
            readonly 'obfs-opts': {
                readonly host?: string | undefined;
                readonly mode: "tls" | "http" | undefined;
            };
            readonly password?: undefined;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly udp?: undefined;
            readonly username?: undefined;
            readonly tls?: undefined;
            readonly 'skip-cert-verify'?: undefined;
        } | {
            readonly type: "http";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly username: string;
            readonly password: string;
            readonly tls: true;
            readonly 'skip-cert-verify': boolean;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly udp?: undefined;
        } | {
            readonly type: "http";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly username: string;
            readonly password: string;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly udp?: undefined;
            readonly tls?: undefined;
            readonly 'skip-cert-verify'?: undefined;
        } | {
            readonly network?: string | undefined;
            readonly 'ws-opts'?: {
                path: string;
                headers?: undefined;
            } | undefined;
            readonly 'skip-cert-verify': boolean;
            readonly sni?: string | undefined;
            readonly alpn?: [string, ...string[]] | undefined;
            readonly udp?: true | undefined;
            readonly type: "trojan";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly password: string;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly username?: undefined;
            readonly tls?: undefined;
        } | {
            readonly udp?: boolean | undefined;
            readonly 'skip-cert-verify'?: boolean | undefined;
            readonly tls?: boolean | undefined;
            readonly password?: string | undefined;
            readonly username?: string | undefined;
            readonly type: "socks5";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
        } | {
            readonly alpn?: [string, ...string[]] | undefined;
            readonly type: "tuic";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly udp: true;
            readonly password?: undefined;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly username?: undefined;
            readonly tls?: undefined;
            readonly 'skip-cert-verify'?: undefined;
        } | {
            readonly alpn?: [string, ...string[]] | undefined;
            readonly type: "hysteria2";
            readonly name: string;
            readonly server: string;
            readonly port: string | number;
            readonly up: number;
            readonly down: number;
            readonly password?: undefined;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly udp?: undefined;
            readonly username?: undefined;
            readonly tls?: undefined;
            readonly 'skip-cert-verify'?: undefined;
        } | {
            readonly reserved?: number[] | undefined;
            readonly 'preshared-key'?: string | undefined;
            readonly udp: true;
            readonly server: string;
            readonly port: number;
            readonly 'public-key': string;
            readonly dns?: [string, ...string[]] | undefined;
            readonly mtu?: number | undefined;
            readonly ipv6?: string | undefined;
            readonly type: "wireguard";
            readonly name: string;
            readonly 'private-key': string;
            readonly ip: string;
            readonly password?: undefined;
            readonly obfs?: undefined;
            readonly protocol?: undefined;
            readonly cipher?: undefined;
            readonly 'obfs-param'?: undefined;
            readonly 'protocol-param'?: undefined;
            readonly username?: undefined;
            readonly tls?: undefined;
            readonly 'skip-cert-verify'?: undefined;
        } | null>[];
        readonly getClashNodeNames: (list: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined, prependNodeNames?: readonly string[] | undefined, defaultNodeNames?: readonly string[] | undefined) => readonly string[];
        readonly getSurgeNodes: (nodeList: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => string;
        readonly getSurgeNodeNames: (nodeList: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => string;
        readonly getSurgeWireguardNodes: (nodeList: readonly PossibleNodeConfigType[]) => string;
        readonly getSurfboardNodes: (list: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => string;
        readonly getSurfboardNodeNames: (list: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => string;
        readonly getShadowsocksNodes: (list: readonly import("../types").ShadowsocksNodeConfig[], groupName?: string) => string;
        readonly getShadowsocksNodesJSON: (list: readonly import("../types").ShadowsocksNodeConfig[]) => string;
        readonly getShadowsocksrNodes: (list: readonly import("../types").ShadowsocksrNodeConfig[], groupName: string) => string;
        readonly getV2rayNNodes: (list: readonly import("../types").VmessNodeConfig[]) => string;
        readonly getQuantumultXNodes: (nodeList: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => string;
        readonly getQuantumultXNodeNames: (nodeList: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => string;
        readonly getLoonNodes: (list: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined) => string;
        readonly getLoonNodeNames: (list: readonly PossibleNodeConfigType[], filter?: ((nodeConfig: PossibleNodeConfigType) => boolean) | {
            readonly filter: <T extends PossibleNodeConfigType>(nodeList: readonly T[]) => readonly T[];
            readonly supportSort: true;
        } | undefined, separator?: string | undefined) => string;
        readonly toUrlSafeBase64: (str: string) => string;
        readonly toBase64: (str: string) => string;
        readonly encodeURIComponent: typeof encodeURIComponent;
    };
    init(params?: {
        getNodeListParams?: GetNodeListParams;
    }): Promise<this>;
    getMergedCustomParams(extendableCustomParams?: Record<string, any>): Readonly<Record<string, any>>;
    render(templateEngine?: Environment, extendRenderContext?: ExtendableRenderContext): string;
    private providerMapper;
}
