import _ from 'lodash';
import { NodeFilterType, PossibleNodeConfigType, SortedNodeFilterType } from '../types';
export declare const getClashNodes: (list: ReadonlyArray<PossibleNodeConfigType>, filter?: NodeFilterType | SortedNodeFilterType) => NonNullable<{
    plugin?: string | undefined;
    readonly 'client-fingerprint'?: string | undefined;
    'plugin-opts'?: {
        mode: "tls" | "http" | "ws" | "wss";
        host: string | undefined;
    } | {
        host: string | undefined;
        path: string;
        mux: boolean;
        headers: _.Omit<Record<string, string>, "host">;
        'skip-cert-verify'?: boolean | undefined;
        mode: string;
        tls: boolean;
    } | {
        host?: string | undefined;
        version?: string | number | undefined;
        password: string;
        mode?: undefined;
    } | undefined;
    readonly type: "ss";
    readonly cipher: string;
    readonly name: string;
    readonly password: string;
    readonly port: string | number;
    readonly server: string;
    readonly udp: boolean;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly username?: undefined;
    readonly tls?: undefined;
    readonly 'skip-cert-verify'?: undefined;
} | {
    readonly 'ws-opts'?: {
        path: string | undefined;
        headers: {
            host?: string | undefined;
        };
    } | undefined;
    readonly 'skip-cert-verify'?: boolean | undefined;
    readonly tls: boolean;
    readonly network?: "ws" | undefined;
    readonly type: "vmess";
    readonly cipher: "none" | "aes-128-gcm" | "chacha20-ietf-poly1305" | "auto";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly udp: boolean;
    readonly uuid: string;
    readonly alterId: string | number;
    readonly password?: undefined;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly username?: undefined;
} | {
    readonly type: "ssr";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly password: string;
    readonly obfs: string;
    readonly protocol: string;
    readonly cipher: string;
    readonly 'obfs-param': string;
    readonly 'protocol-param': string;
    readonly udp: boolean;
    readonly username?: undefined;
    readonly tls?: undefined;
    readonly 'skip-cert-verify'?: undefined;
} | {
    readonly version?: string | number | undefined;
    readonly type: "snell";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly psk: string;
    readonly 'obfs-opts': {
        readonly host?: string | undefined;
        readonly mode: "tls" | "http" | undefined;
    };
    readonly password?: undefined;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly udp?: undefined;
    readonly username?: undefined;
    readonly tls?: undefined;
    readonly 'skip-cert-verify'?: undefined;
} | {
    readonly type: "http";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly username: string;
    readonly password: string;
    readonly tls: true;
    readonly 'skip-cert-verify': boolean;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly udp?: undefined;
} | {
    readonly type: "http";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly username: string;
    readonly password: string;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly udp?: undefined;
    readonly tls?: undefined;
    readonly 'skip-cert-verify'?: undefined;
} | {
    readonly network?: string | undefined;
    readonly 'ws-opts'?: {
        path: string;
        headers?: undefined;
    } | undefined;
    readonly 'skip-cert-verify': boolean;
    readonly sni?: string | undefined;
    readonly alpn?: [string, ...string[]] | undefined;
    readonly udp?: true | undefined;
    readonly type: "trojan";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly password: string;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly username?: undefined;
    readonly tls?: undefined;
} | {
    readonly udp?: boolean | undefined;
    readonly 'skip-cert-verify'?: boolean | undefined;
    readonly tls?: boolean | undefined;
    readonly password?: string | undefined;
    readonly username?: string | undefined;
    readonly type: "socks5";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
} | {
    readonly alpn?: [string, ...string[]] | undefined;
    readonly type: "tuic";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly udp: true;
    readonly password?: undefined;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly username?: undefined;
    readonly tls?: undefined;
    readonly 'skip-cert-verify'?: undefined;
} | {
    readonly alpn?: [string, ...string[]] | undefined;
    readonly type: "hysteria2";
    readonly name: string;
    readonly server: string;
    readonly port: string | number;
    readonly up: number;
    readonly down: number;
    readonly password?: undefined;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly udp?: undefined;
    readonly username?: undefined;
    readonly tls?: undefined;
    readonly 'skip-cert-verify'?: undefined;
} | {
    readonly reserved?: number[] | undefined;
    readonly 'preshared-key'?: string | undefined;
    readonly udp: true;
    readonly server: string;
    readonly port: number;
    readonly 'public-key': string;
    readonly dns?: [string, ...string[]] | undefined;
    readonly mtu?: number | undefined;
    readonly ipv6?: string | undefined;
    readonly type: "wireguard";
    readonly name: string;
    readonly 'private-key': string;
    readonly ip: string;
    readonly password?: undefined;
    readonly obfs?: undefined;
    readonly protocol?: undefined;
    readonly cipher?: undefined;
    readonly 'obfs-param'?: undefined;
    readonly 'protocol-param'?: undefined;
    readonly username?: undefined;
    readonly tls?: undefined;
    readonly 'skip-cert-verify'?: undefined;
} | null>[];
export declare const getClashNodeNames: (list: ReadonlyArray<PossibleNodeConfigType>, filter?: NodeFilterType | SortedNodeFilterType, prependNodeNames?: ReadonlyArray<string>, defaultNodeNames?: ReadonlyArray<string>) => ReadonlyArray<string>;
