"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseSSUri = void 0;
const logger_1 = require("@surgio/logger");
const url_1 = require("url");
const types_1 = require("../types");
const index_1 = require("./index");
const logger = (0, logger_1.createLogger)({ service: 'surgio:utils:ss' });
const parseSSUri = (str) => {
    logger.debug('Shadowsocks URI', str);
    const scheme = new url_1.URL(str);
    const pluginString = scheme.searchParams.get('plugin');
    const userInfo = (0, index_1.fromUrlSafeBase64)(decodeURIComponent(scheme.username)).split(':');
    const pluginInfo = typeof pluginString === 'string'
        ? (0, index_1.decodeStringList)(pluginString.split(';'))
        : {};
    return {
        type: types_1.NodeTypeEnum.Shadowsocks,
        nodeName: decodeURIComponent(scheme.hash.replace('#', '')),
        hostname: scheme.hostname,
        port: scheme.port,
        method: userInfo[0],
        password: userInfo[1],
        ...(pluginInfo['obfs-local']
            ? {
                obfs: pluginInfo.obfs,
                obfsHost: pluginInfo['obfs-host'] + '',
            }
            : null),
        ...(pluginInfo['simple-obfs']
            ? {
                obfs: pluginInfo.obfs,
                obfsHost: pluginInfo['obfs-host'] + '',
            }
            : null),
        ...(pluginInfo['v2ray-plugin']
            ? {
                obfs: pluginInfo.tls ? 'wss' : 'ws',
                obfsHost: pluginInfo.host + '',
            }
            : null),
    };
};
exports.parseSSUri = parseSSUri;
//# sourceMappingURL=ss.js.map