import { z } from 'zod';
import { NodeTypeEnum } from '../types';
export declare const VmessNodeConfigValidator: z.ZodObject<{
    surgeConfig: z.ZodOptional<z.ZodObject<{
        resolveHostname: z.ZodOptional<z.ZodBoolean>;
        vmessAEAD: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    }, {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    }>>;
    surfboardConfig: z.ZodOptional<z.ZodObject<{
        vmessAEAD: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        vmessAEAD?: boolean | undefined;
    }, {
        vmessAEAD?: boolean | undefined;
    }>>;
    quantumultXConfig: z.ZodOptional<z.ZodObject<{
        vmessAEAD: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        vmessAEAD?: boolean | undefined;
    }, {
        vmessAEAD?: boolean | undefined;
    }>>;
    clashConfig: z.ZodOptional<z.ZodObject<{
        enableTuic: z.ZodOptional<z.ZodBoolean>;
        enableShadowTls: z.ZodOptional<z.ZodBoolean>;
        enableHysteria2: z.ZodOptional<z.ZodBoolean>;
        clashCore: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"clash">, z.ZodLiteral<"clash.meta">, z.ZodLiteral<"stash">]>>;
    }, "strip", z.ZodTypeAny, {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    }, {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    }>>;
    mptcp: z.ZodOptional<z.ZodBoolean>;
    tfo: z.ZodOptional<z.ZodBoolean>;
    underlyingProxy: z.ZodOptional<z.ZodString>;
    nodeName: z.ZodString;
    enable: z.ZodOptional<z.ZodBoolean>;
    ecn: z.ZodOptional<z.ZodBoolean>;
    shadowTls: z.ZodOptional<z.ZodObject<{
        version: z.ZodOptional<z.ZodEffects<z.ZodUnion<[z.ZodString, z.ZodNumber]>, string | number, string | number>>;
        password: z.ZodString;
        sni: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        password: string;
        sni: string;
        version?: string | number | undefined;
    }, {
        password: string;
        sni: string;
        version?: string | number | undefined;
    }>>;
    testUrl: z.ZodOptional<z.ZodString>;
    type: z.ZodLiteral<NodeTypeEnum.Vmess>;
    hostname: z.ZodString;
    port: z.ZodEffects<z.ZodUnion<[z.ZodString, z.ZodNumber]>, string | number, string | number>;
    method: z.ZodUnion<[z.ZodLiteral<"none">, z.ZodLiteral<"aes-128-gcm">, z.ZodLiteral<"chacha20-ietf-poly1305">, z.ZodLiteral<"auto">]>;
    uuid: z.ZodString;
    alterId: z.ZodEffects<z.ZodUnion<[z.ZodString, z.ZodNumber]>, string | number, string | number>;
    network: z.ZodUnion<[z.ZodLiteral<"tcp">, z.ZodLiteral<"ws">]>;
    tls: z.ZodBoolean;
    host: z.ZodOptional<z.ZodString>;
    path: z.ZodOptional<z.ZodString>;
    udpRelay: z.ZodOptional<z.ZodBoolean>;
    tls13: z.ZodOptional<z.ZodBoolean>;
    skipCertVerify: z.ZodOptional<z.ZodBoolean>;
    wsHeaders: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    serverCertFingerprintSha256: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    port: string | number;
    type: NodeTypeEnum.Vmess;
    nodeName: string;
    hostname: string;
    method: "none" | "aes-128-gcm" | "chacha20-ietf-poly1305" | "auto";
    tls: boolean;
    uuid: string;
    alterId: string | number;
    network: "ws" | "tcp";
    surgeConfig?: {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    } | undefined;
    surfboardConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    quantumultXConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    clashConfig?: {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    } | undefined;
    mptcp?: boolean | undefined;
    tfo?: boolean | undefined;
    underlyingProxy?: string | undefined;
    enable?: boolean | undefined;
    ecn?: boolean | undefined;
    shadowTls?: {
        password: string;
        sni: string;
        version?: string | number | undefined;
    } | undefined;
    testUrl?: string | undefined;
    host?: string | undefined;
    path?: string | undefined;
    udpRelay?: boolean | undefined;
    tls13?: boolean | undefined;
    skipCertVerify?: boolean | undefined;
    wsHeaders?: Record<string, string> | undefined;
    serverCertFingerprintSha256?: string | undefined;
}, {
    port: string | number;
    type: NodeTypeEnum.Vmess;
    nodeName: string;
    hostname: string;
    method: "none" | "aes-128-gcm" | "chacha20-ietf-poly1305" | "auto";
    tls: boolean;
    uuid: string;
    alterId: string | number;
    network: "ws" | "tcp";
    surgeConfig?: {
        resolveHostname?: boolean | undefined;
        vmessAEAD?: boolean | undefined;
    } | undefined;
    surfboardConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    quantumultXConfig?: {
        vmessAEAD?: boolean | undefined;
    } | undefined;
    clashConfig?: {
        enableTuic?: boolean | undefined;
        enableShadowTls?: boolean | undefined;
        enableHysteria2?: boolean | undefined;
        clashCore?: "clash" | "clash.meta" | "stash" | undefined;
    } | undefined;
    mptcp?: boolean | undefined;
    tfo?: boolean | undefined;
    underlyingProxy?: string | undefined;
    enable?: boolean | undefined;
    ecn?: boolean | undefined;
    shadowTls?: {
        password: string;
        sni: string;
        version?: string | number | undefined;
    } | undefined;
    testUrl?: string | undefined;
    host?: string | undefined;
    path?: string | undefined;
    udpRelay?: boolean | undefined;
    tls13?: boolean | undefined;
    skipCertVerify?: boolean | undefined;
    wsHeaders?: Record<string, string> | undefined;
    serverCertFingerprintSha256?: string | undefined;
}>;
